class HEXRenkler:
    bordo = "#800000"
    koyu_kirmizi = "#8B0000"
    kahverengi = "#A52A2A"
    ates_tuglasi = "#B22222"
    kizil = "#DC143C"
    kirmizi = "#FF0000"
    domates = "#FF6347"
    mercan = "#FF7F50"
    hint_kirmizisi = "#CD5C5C"
    hafif_mercan = "#F08080"
    koyu_somon = "#E9967A"
    somon = "#FA8072"
    hafif_somon = "#FFA07A"
    turuncu_kirmizi = "#FF4500"
    koyu_turuncu = "#FF8C00"
    portakal = "#FFA500"
    altin = "#FFD700"
    koyu_altin_cubuk = "#B8860B"
    altin_cubuk = "#DAA520"
    soluk_altin_cubuk = "#EEE8AA"
    koyu_haki = "#BDB76B"
    haki = "#F0E68C"
    zeytin = "#808000"
    sari = "#FFFF00"
    sari_yesil = "#9ACD32"
    koyu_zeytin_yesili = "#556B2F"
    zeytin_yesili = "#6B8E23"
    yesil_cimen = "#7CFC00"
    grafigin_yeniden_kullanimi = "#7FFF00"
    yesil_sari = "#ADFF2F"
    koyu_yesil = "#006400"
    yesil = "#008000"
    orman_yesili = "#228B22"
    misket_limonu = "#00FF00"
    limon_yesili = "#32CD32"
    acik_yesil = "#90EE90"
    soluk_yesil = "#98FB98"
    koyu_deniz_yesili = "#8FBC8F"
    orta_bahar_yesili = "#00FA9A"
    ilkbahar_yesili = "#00FF7F"
    deniz_yesili = "#2E8B57"
    orta_su_denizi = "#66CDAA"
    orta_deniz_yesili = "#3CB371"
    acik_deniz_yesili = "#20B2AA"
    koyu_arduvaz_grisi = "#2F4F4F"
    camurcun = "#008080"
    koyu_camgobegi = "#008B8B"
    su = "#00FFFF"
    camgobegi = "#00FFFF"
    acik_cam_gobegi = "#E0FFFF"
    koyu_turkuaz = "#00CED1"
    turkuaz = "#40E0D0"
    orta_turkuaz = "#48D1CC"
    soluk_turkuaz = "#AFEEEE"
    aqua_marine = "#7FFFD4"
    toz_mavi = "#B0E0E6"
    harbiyeli_mavisi = "#5F9EA0"
    celik_mavisi = "#4682B4"
    misir_cicegi_mavisi = "#6495ED"
    derin_gok_mavisi = "#00BFFF"
    kacak_mavi = "#1E90FF"
    acik_mavi = "#ADD8E6"
    gokyuzu_mavi = "#87CEEB"
    acik_gok_mavisi = "#87CEFA"
    gece_yarisi_mavisi = "#191970"
    donanma = "#000080"
    koyu_mavi = "#00008B"
    orta_mavi = "#0000CD"
    mavi = "#0000FF"
    kraliyet_mavisi = "#4169E1"
    mavi_menekse = "#8A2BE2"
    civit = "#4B0082"
    koyu_barut_mavisi = "#483D8B"
    barut_mavisi = "#6A5ACD"
    orta_barut_mavisi = "#7B68EE"
    orta_mor = "#9370DB"
    koyu_macenta = "#8B008B"
    koyu_mor = "#9400D3"
    koyu_orkide = "#9932CC"
    orta_boy_orkide = "#BA55D3"
    mor = "#800080"
    devedikeni = "#D8BFD8"
    erik = "#DDA0DD"
    menekse = "#EE82EE"
    eflatun = "#FF00FF"
    orta_menekse_kirmizi = "#C71585"
    soluk_menekse_kirmizi = "#DB7093"
    derin_pembe = "#FF1493"
    sicak_pembe = "#FF69B4"
    acik_pembe = "#FFB6C1"
    pembe = "#FFC0CB"
    antik_beyaz = "#FAEBD7"
    bej = "#F5F5DC"
    bisque = "#FFE4C4"
    beyazlatilmis_badem = "#FFEBCD"
    bugday = "#F5DEB3"
    misir_puskulu = "#FFF8DC"
    limonlu_sifon = "#FFFACD"
    acik_altin_cubuk_sarisi = "#FAFAD2"
    acik_sari = "#FFFFE0"
    eyer_kahverengi = "#8B4513"
    sienna = "#A0522D"
    cikolata = "#D2691E"
    peru = "#CD853F"
    kumlu_kahverengi = "#F4A460"
    iri_odun = "#DEB887"
    bronzluk = "#D2B48C"
    pembe_kahverengi = "#BC8F8F"
    mokasen = "#FFE4B5"
    navajo_beyazi = "#FFDEAD"
    seftali_pufu = "#FFDAB9"
    puslu_gul = "#FFE4E1"
    lavanta_allik = "#FFF0F5"
    keten = "#FAF0E6"
    eski_dantel = "#FDF5E6"
    papaya_kirbaci = "#FFEFD5"
    deniz_kabugu = "#FFF5EE"
    nane_kremasi = "#F5FFFA"
    barut_grisi = "#708090"
    acik_barut_grisi = "#778899"
    acik_celik_mavisi = "#B0C4DE"
    lavanta = "#E6E6FA"
    cicek_beyazi = "#FFFAF0"
    alice_mavi = "#F0F8FF"
    hayalet_beyaz = "#F8F8FF"
    seker_kavunu = "#F0FFF0"
    fildisi = "#FFFFF0"
    gok_mavisi = "#F0FFFF"
    kar = "#FFFAFA"
    siyah = "#000000"
    soluk_gri = "#696969"
    gri = "#808080"
    koyu_gri = "#A9A9A9"
    gumus = "#C0C0C0"
    acik_gri = "#D3D3D3"
    gainsboro = "#DCDCDC"
    beyaz_duman = "#F5F5F5"
    beyaz = "#FFFFFF"
