from .utils import convert_color_to_ansi, hex_to_rgb
from .hex import HEXRenkler
from .rgb import RGBRenkler
from ._print import print

__all__ = [
    "HEXRenkler",
    "RGBRenkler",
    "convert_color_to_ansi",
    "hex_to_rgb",
    "print",
]


class RGBRenkler:
    bordo = convert_color_to_ansi((128, 0, 0))  # '#800000'
    koyu_kirmizi = convert_color_to_ansi((139, 0, 0))  # '#8B0000'
    kahverengi = convert_color_to_ansi((165, 42, 42))  # '#A52A2A'
    ates_tuglasi = convert_color_to_ansi((178, 34, 34))  # '#B22222'
    kizil = convert_color_to_ansi((220, 20, 60))  # '#DC143C'
    kirmizi = convert_color_to_ansi((255, 0, 0))  # '#FF0000'
    domates = convert_color_to_ansi((255, 99, 71))  # '#FF6347'
    mercan = convert_color_to_ansi((255, 127, 80))  # '#FF7F50'
    hint_kirmizisi = convert_color_to_ansi((205, 92, 92))  # '#CD5C5C'
    hafif_mercan = convert_color_to_ansi((240, 128, 128))  # '#F08080'
    koyu_somon = convert_color_to_ansi((233, 150, 122))  # '#E9967A'
    somon = convert_color_to_ansi((250, 128, 114))  # '#FA8072'
    hafif_somon = convert_color_to_ansi((255, 160, 122))  # '#FFA07A'
    turuncu_kirmizi = convert_color_to_ansi((255, 69, 0))  # '#FF4500'
    koyu_turuncu = convert_color_to_ansi((255, 140, 0))  # '#FF8C00'
    portakal = convert_color_to_ansi((255, 165, 0))  # '#FFA500'
    altin = convert_color_to_ansi((255, 215, 0))  # '#FFD700'
    koyu_altin_cubuk = convert_color_to_ansi((184, 134, 11))  # '#B8860B'
    altin_cubuk = convert_color_to_ansi((218, 165, 32))  # '#DAA520'
    soluk_altin_cubuk = convert_color_to_ansi((238, 232, 170))  # '#EEE8AA'
    koyu_haki = convert_color_to_ansi((189, 183, 107))  # '#BDB76B'
    haki = convert_color_to_ansi((240, 230, 140))  # '#F0E68C'
    zeytin = convert_color_to_ansi((128, 128, 0))  # '#808000'
    sari = convert_color_to_ansi((255, 255, 0))  # '#FFFF00'
    sari_yesil = convert_color_to_ansi((154, 205, 50))  # '#9ACD32'
    koyu_zeytin_yesili = convert_color_to_ansi((85, 107, 47))  # '#556B2F'
    zeytin_yesili = convert_color_to_ansi((107, 142, 35))  # '#6B8E23'
    yesil_cimen = convert_color_to_ansi((124, 252, 0))  # '#7CFC00'
    grafigin_yeniden_kullanimi = convert_color_to_ansi((127, 255, 0))  # '#7FFF00'
    yesil_sari = convert_color_to_ansi((173, 255, 47))  # '#ADFF2F'
    koyu_yesil = convert_color_to_ansi((0, 100, 0))  # '#006400'
    yesil = convert_color_to_ansi((0, 128, 0))  # '#008000'
    orman_yesili = convert_color_to_ansi((34, 139, 34))  # '#228B22'
    misket_limonu = convert_color_to_ansi((0, 255, 0))  # '#00FF00'
    limon_yesili = convert_color_to_ansi((50, 205, 50))  # '#32CD32'
    acik_yesil = convert_color_to_ansi((144, 238, 144))  # '#90EE90'
    soluk_yesil = convert_color_to_ansi((152, 251, 152))  # '#98FB98'
    koyu_deniz_yesili = convert_color_to_ansi((143, 188, 143))  # '#8FBC8F'
    orta_bahar_yesili = convert_color_to_ansi((0, 250, 154))  # '#00FA9A'
    ilkbahar_yesili = convert_color_to_ansi((0, 255, 127))  # '#00FF7F'
    deniz_yesili = convert_color_to_ansi((46, 139, 87))  # '#2E8B57'
    orta_su_denizi = convert_color_to_ansi((102, 205, 170))  # '#66CDAA'
    orta_deniz_yesili = convert_color_to_ansi((60, 179, 113))  # '#3CB371'
    acik_deniz_yesili = convert_color_to_ansi((32, 178, 170))  # '#20B2AA'
    koyu_arduvaz_grisi = convert_color_to_ansi((47, 79, 79))  # '#2F4F4F'
    camurcun = convert_color_to_ansi((0, 128, 128))  # '#008080'
    koyu_camgobegi = convert_color_to_ansi((0, 139, 139))  # '#008B8B'
    su = convert_color_to_ansi((0, 255, 255))  # '#00FFFF'
    camgobegi = convert_color_to_ansi((0, 255, 255))  # '#00FFFF'
    acik_cam_gobegi = convert_color_to_ansi((224, 255, 255))  # '#E0FFFF'
    koyu_turkuaz = convert_color_to_ansi((0, 206, 209))  # '#00CED1'
    turkuaz = convert_color_to_ansi((64, 224, 208))  # '#40E0D0'
    orta_turkuaz = convert_color_to_ansi((72, 209, 204))  # '#48D1CC'
    soluk_turkuaz = convert_color_to_ansi((175, 238, 238))  # '#AFEEEE'
    aqua_marine = convert_color_to_ansi((127, 255, 212))  # '#7FFFD4'
    toz_mavi = convert_color_to_ansi((176, 224, 230))  # '#B0E0E6'
    harbiyeli_mavisi = convert_color_to_ansi((95, 158, 160))  # '#5F9EA0'
    celik_mavisi = convert_color_to_ansi((70, 130, 180))  # '#4682B4'
    misir_cicegi_mavisi = convert_color_to_ansi((100, 149, 237))  # '#6495ED'
    derin_gok_mavisi = convert_color_to_ansi((0, 191, 255))  # '#00BFFF'
    kacak_mavi = convert_color_to_ansi((30, 144, 255))  # '#1E90FF'
    acik_mavi = convert_color_to_ansi((173, 216, 230))  # '#ADD8E6'
    gokyuzu_mavi = convert_color_to_ansi((135, 206, 235))  # '#87CEEB'
    acik_gok_mavisi = convert_color_to_ansi((135, 206, 250))  # '#87CEFA'
    gece_yarisi_mavisi = convert_color_to_ansi((25, 25, 112))  # '#191970'
    donanma = convert_color_to_ansi((0, 0, 128))  # '#000080'
    koyu_mavi = convert_color_to_ansi((0, 0, 139))  # '#00008B'
    orta_mavi = convert_color_to_ansi((0, 0, 205))  # '#0000CD'
    mavi = convert_color_to_ansi((0, 0, 255))  # '#0000FF'
    kraliyet_mavisi = convert_color_to_ansi((65, 105, 225))  # '#4169E1'
    mavi_menekse = convert_color_to_ansi((138, 43, 226))  # '#8A2BE2'
    civit = convert_color_to_ansi((75, 0, 130))  # '#4B0082'
    koyu_barut_mavisi = convert_color_to_ansi((72, 61, 139))  # '#483D8B'
    barut_mavisi = convert_color_to_ansi((106, 90, 205))  # '#6A5ACD'
    orta_barut_mavisi = convert_color_to_ansi((123, 104, 238))  # '#7B68EE'
    orta_mor = convert_color_to_ansi((147, 112, 219))  # '#9370DB'
    koyu_macenta = convert_color_to_ansi((139, 0, 139))  # '#8B008B'
    koyu_mor = convert_color_to_ansi((148, 0, 211))  # '#9400D3'
    koyu_orkide = convert_color_to_ansi((153, 50, 204))  # '#9932CC'
    orta_boy_orkide = convert_color_to_ansi((186, 85, 211))  # '#BA55D3'
    mor = convert_color_to_ansi((128, 0, 128))  # '#800080'
    devedikeni = convert_color_to_ansi((216, 191, 216))  # '#D8BFD8'
    erik = convert_color_to_ansi((221, 160, 221))  # '#DDA0DD'
    menekse = convert_color_to_ansi((238, 130, 238))  # '#EE82EE'
    eflatun = convert_color_to_ansi((255, 0, 255))  # '#FF00FF'
    orta_menekse_kirmizi = convert_color_to_ansi((199, 21, 133))  # '#C71585'
    soluk_menekse_kirmizi = convert_color_to_ansi((219, 112, 147))  # '#DB7093'
    derin_pembe = convert_color_to_ansi((255, 20, 147))  # '#FF1493'
    sicak_pembe = convert_color_to_ansi((255, 105, 180))  # '#FF69B4'
    acik_pembe = convert_color_to_ansi((255, 182, 193))  # '#FFB6C1'
    pembe = convert_color_to_ansi((255, 192, 203))  # '#FFC0CB'
    antik_beyaz = convert_color_to_ansi((250, 235, 215))  # '#FAEBD7'
    bej = convert_color_to_ansi((245, 245, 220))  # '#F5F5DC'
    bisque = convert_color_to_ansi((255, 228, 196))  # '#FFE4C4'
    beyazlatilmis_badem = convert_color_to_ansi((255, 235, 205))  # '#FFEBCD'
    bugday = convert_color_to_ansi((245, 222, 179))  # '#F5DEB3'
    misir_puskulu = convert_color_to_ansi((255, 248, 220))  # '#FFF8DC'
    limonlu_sifon = convert_color_to_ansi((255, 250, 205))  # '#FFFACD'
    acik_altin_cubuk_sarisi = convert_color_to_ansi((250, 250, 210))  # '#FAFAD2'
    acik_sari = convert_color_to_ansi((255, 255, 224))  # '#FFFFE0'
    eyer_kahverengi = convert_color_to_ansi((139, 69, 19))  # '#8B4513'
    sienna = convert_color_to_ansi((160, 82, 45))  # '#A0522D'
    cikolata = convert_color_to_ansi((210, 105, 30))  # '#D2691E'
    peru = convert_color_to_ansi((205, 133, 63))  # '#CD853F'
    kumlu_kahverengi = convert_color_to_ansi((244, 164, 96))  # '#F4A460'
    iri_odun = convert_color_to_ansi((222, 184, 135))  # '#DEB887'
    bronzluk = convert_color_to_ansi((210, 180, 140))  # '#D2B48C'
    pembe_kahverengi = convert_color_to_ansi((188, 143, 143))  # '#BC8F8F'
    mokasen = convert_color_to_ansi((255, 228, 181))  # '#FFE4B5'
    navajo_beyazi = convert_color_to_ansi((255, 222, 173))  # '#FFDEAD'
    seftali_pufu = convert_color_to_ansi((255, 218, 185))  # '#FFDAB9'
    puslu_gul = convert_color_to_ansi((255, 228, 225))  # '#FFE4E1'
    lavanta_allik = convert_color_to_ansi((255, 240, 245))  # '#FFF0F5'
    keten = convert_color_to_ansi((250, 240, 230))  # '#FAF0E6'
    eski_dantel = convert_color_to_ansi((253, 245, 230))  # '#FDF5E6'
    papaya_kirbaci = convert_color_to_ansi((255, 239, 213))  # '#FFEFD5'
    deniz_kabugu = convert_color_to_ansi((255, 245, 238))  # '#FFF5EE'
    nane_kremasi = convert_color_to_ansi((245, 255, 250))  # '#F5FFFA'
    barut_grisi = convert_color_to_ansi((112, 128, 144))  # '#708090'
    acik_barut_grisi = convert_color_to_ansi((119, 136, 153))  # '#778899'
    acik_celik_mavisi = convert_color_to_ansi((176, 196, 222))  # '#B0C4DE'
    lavanta = convert_color_to_ansi((230, 230, 250))  # '#E6E6FA'
    cicek_beyazi = convert_color_to_ansi((255, 250, 240))  # '#FFFAF0'
    alice_mavi = convert_color_to_ansi((240, 248, 255))  # '#F0F8FF'
    hayalet_beyaz = convert_color_to_ansi((248, 248, 255))  # '#F8F8FF'
    seker_kavunu = convert_color_to_ansi((240, 255, 240))  # '#F0FFF0'
    fildisi = convert_color_to_ansi((255, 255, 240))  # '#FFFFF0'
    gok_mavisi = convert_color_to_ansi((240, 255, 255))  # '#F0FFFF'
    kar = convert_color_to_ansi((255, 250, 250))  # '#FFFAFA'
    siyah = convert_color_to_ansi((0, 0, 0))  # '#000000'
    soluk_gri = convert_color_to_ansi((105, 105, 105))  # '#696969'
    gri = convert_color_to_ansi((128, 128, 128))  # '#808080'
    koyu_gri = convert_color_to_ansi((169, 169, 169))  # '#A9A9A9'
    gumus = convert_color_to_ansi((192, 192, 192))  # '#C0C0C0'
    acik_gri = convert_color_to_ansi((211, 211, 211))  # '#D3D3D3'
    gainsboro = convert_color_to_ansi((220, 220, 220))  # '#DCDCDC'
    beyaz_duman = convert_color_to_ansi((245, 245, 245))  # '#F5F5F5'
    beyaz = convert_color_to_ansi((255, 255, 255))  # '#FFFFFF'
